@@ -1,5 +1,5 @@
 package App::gimpgitbuild::Command::build;
-$App::gimpgitbuild::Command::build::VERSION = '0.0.2';
+$App::gimpgitbuild::Command::build::VERSION = '0.2.0';
 use strict;
 use warnings;
 use 5.014;
@@ -8,6 +8,8 @@ use App::gimpgitbuild -command;
 
 use Path::Tiny qw/ path tempdir tempfile cwd /;
 
+use App::gimpgitbuild::API::GitBuild ();
+
 sub description
 {
     return "build gimp from git";
@@ -76,25 +78,18 @@ sub execute
     my $output_fn = $opt->{output};
     my $exe       = $opt->{exec} // [];
 
-    my $fh = \*STDIN;
+    my $fh  = \*STDIN;
+    my $obj = App::gimpgitbuild::API::GitBuild->new;
 
-    my $HOME      = $ENV{HOME};
-    my $gegl_p    = "$HOME/apps/graphics/gegl";
-    my $babl_p    = "$HOME/apps/graphics/babl";
-    my $mypaint_p = "$HOME/apps/graphics/libmypaint";
-    $ENV{PATH}            = "$gegl_p/bin:$ENV{PATH}";
-    $ENV{PKG_CONFIG_PATH} = join(
-        ":",
-        (
-            map {
-                my $p = $_;
-                map { "$p/$_/pkgconfig" } qw# share lib64 lib  #
-            } ( $babl_p, $gegl_p, $mypaint_p )
-        ),
-        ( $ENV{PKG_CONFIG_PATH} // '' )
-    );
-    $ENV{XDG_DATA_DIRS} =
-"$gegl_p/share:$mypaint_p/share:$mypaint_p/share/pkgconfig:$babl_p/share:$ENV{XDG_DATA_DIRS}";
+    my $HOME             = $obj->home_dir;
+    my $install_base_dir = $obj->install_base_dir;
+    my $gegl_p           = "$install_base_dir/gegl";
+    my $babl_p           = "$install_base_dir/babl";
+    my $mypaint_p        = "$install_base_dir/libmypaint";
+    my $env              = $obj->new_env;
+    $ENV{PATH}            = $env->{PATH};
+    $ENV{PKG_CONFIG_PATH} = $env->{PKG_CONFIG_PATH};
+    $ENV{XDG_DATA_DIRS}   = $env->{XDG_DATA_DIRS};
 
     my $GNOME_GIT = 'https://gitlab.gnome.org/GNOME';
     _git_build(
@@ -161,7 +156,7 @@ __END__
 
 =head1 VERSION
 
-version 0.0.2
+version 0.2.0
 
 =begin foo return (
         [ "output|o=s", "Output path" ],
